@@ -14,8 +14,64 @@ getLinePosns <- function(axis.posns, endspace = 0.5)
   return(line.posns)
 }
 
+swapStrip_Title <- function(gp, posns)
+{
+  strip <- paste0("strip-", posns[1])
+  if (posns[1] %in% c("l", "r"))
+    titl <- paste0("ylab-", posns[1])
+  else
+    titl <- paste0("xlab-", posns[1])
+
+  gp_title <- gp$layout[gp$layout[['name']] == titl ,][[posns[1]]]
+  gp_strip <- gp$layout[grepl(strip, gp$layout[['name']]),][[posns[1]]][1]
+
+  gp$layout[gp$layout[['name']] == titl ,][[posns[1]]] <- gp_strip
+  gp$layout[gp$layout[['name']] == titl ,][[posns[2]]] <- gp_strip
+  gp$layout[grepl(strip, gp$layout[['name']]),][[posns[1]]] <- gp_title
+  gp$layout[grepl(strip, gp$layout[['name']]),][[posns[2]]] <- gp_title
+  
+  return(gp)
+}
+
+placeFacetStrips <- function(plt, facetstrips.placement = "inside")
+{
+  # if ( !is.null(facet.y) || !is.null(facet.x))
+  # {
+  if (facetstrips.placement != "inside")
+  {
+    gp <- ggplotGrob(plt)
+    if (any(grepl("strip", gp$layout[['name']])))
+    {  
+      plt <- plt + list(theme(strip.placement = "outside"))
+      if (facetstrips.placement == "outside.title")
+      {
+        gp <- ggplotGrob(plt)
+        #Check if axis and strip are together and swap
+        zno <- which(gp$layout[['name']] == 'xlab-t')
+        if (gp$grobs[zno][[1]]['name'] != "NULL" && any(grepl("strip-t", gp$layout[['name']])))
+          gp <- swapStrip_Title(gp, posns = c("t", "b"))
+        zno <- which(gp$layout[['name']] == 'xlab-b')
+        if (gp$grobs[zno][[1]]['name'][[1]] != "NULL" && any(grepl("strip-b", gp$layout[['name']])))
+          gp <- swapStrip_Title(gp, posns = c("b", "t"))
+        zno <- which(gp$layout[['name']] == 'ylab-r')
+        if (gp$grobs[zno][[1]]['name'] != "NULL" && any(grepl("strip-r", gp$layout[['name']])))
+          gp <- swapStrip_Title(gp, posns = c("r", "l"))
+        zno <- which(gp$layout[['name']] == 'ylab-l')
+        if (gp$grobs[zno][[1]]['name'] != "NULL" && any(grepl("strip-l", gp$layout[['name']])))
+          gp <- swapStrip_Title(gp, c("l", "r"))
+        plt <- ggpubr::as_ggplot(gp)
+      }
+    }
+  }
+  # }
+  
+  return(plt)
+}  
+
 "designGGPlot" <- function(design, labels = NULL, label.size = NULL,
-                           row.factors = "Rows", column.factors = "Columns", scales.free = "free", 
+                           row.factors = "Rows", column.factors = "Columns", 
+                           scales.free = "free", facetstrips.switch = NULL, 
+                           facetstrips.placement = "inside", 
                            cellfillcolour.column=NULL, colour.values=NULL, cellalpha = 1, 
                            celllinetype = "solid", celllinesize = 0.5, celllinecolour = "black",
                            cellheight = 1, cellwidth = 1, 
@@ -27,16 +83,30 @@ getLinePosns <- function(axis.posns, endspace = 0.5)
                            printPlot = TRUE, ggplotFuncs = NULL, ...)
   ## Function that uses ggplot to plot labels on a grid
 {
-  
+  inargs <- list(...)
+  #Check for size, and give error if found
+  inargs <- names(inargs)
+  if (length(inargs) && "size" %in% inargs)
+    stop("Use label.size rather than size to specify the size of the plotted labels.")
+
   opts <- c("top", "bottom")
   x.axis.position <- opts[check.arg.values(x.axis.position, opts)]
+
+  opts <- c("inside", "outside.text", "outside.title")
+  facetstrips.placement <- opts[check.arg.values(facetstrips.placement, opts)]
+  
+  if (!is.null(facetstrips.switch))
+  { 
+    opts <- c("x", "y", "both")
+    facetstrips.switch <- opts[check.arg.values(facetstrips.switch, opts)]
+  }
   
   #Check for multiple factors in either direction
   #Rows
-  if (length(row.factors) == 1) {
+  if (length(row.factors) == 1) 
+  {
     grid.y <- row.factors
     facet.y <- NULL
-    
   } else 
   {
     grid.y <- row.factors[length(row.factors)]
@@ -47,10 +117,10 @@ getLinePosns <- function(axis.posns, endspace = 0.5)
     facet.y <- paste0("vars(", paste(facet.y, collapse = ","), ")")
   }
   #Columns
-  if (length(column.factors) == 1) {
+  if (length(column.factors) == 1) 
+  {
     grid.x <- column.factors
     facet.x <- NULL
-    
   }
   else 
   {
@@ -160,15 +230,18 @@ getLinePosns <- function(axis.posns, endspace = 0.5)
     if (!is.null(facet.y))
       plt <- plt + facet_grid(rows = eval(parse(text=facet.y)), 
                               cols = eval(parse(text=facet.x)), 
-                              labeller = labeller, scales = scales.free, as.table = FALSE)
+                              labeller = labeller, scales = scales.free, 
+                              switch = facetstrips.switch, as.table = FALSE)
     else
       plt <- plt + facet_grid(cols = eval(parse(text=facet.x)), 
-                              labeller = labeller, scales = scales.free, as.table = FALSE)
+                              labeller = labeller, scales = scales.free, 
+                              switch = facetstrips.switch, as.table = FALSE)
   } else
   {
     if (!is.null(facet.y))      
       plt <- plt + facet_grid(rows = eval(parse(text=facet.y)), 
-                              labeller = labeller, scales = scales.free, as.table = FALSE)
+                              labeller = labeller, scales = scales.free, 
+                              switch = facetstrips.switch, as.table = FALSE)
   }
   
   if (!is.null(ggplotFuncs))
@@ -176,18 +249,19 @@ getLinePosns <- function(axis.posns, endspace = 0.5)
     for (f in ggplotFuncs)
       plt <- plt + f
   }
-  
+
   if (!is.null(blockdefinition))
     plt <- designBlocksGGPlot(plt, nrows = nrows, ncolumns = ncolumns, 
                               blocksequence = blocksequence, blockdefinition = blockdefinition, 
                               blocklinecolour = blocklinecolour, blocklinesize = blocklinesize,
-                              printPlot = printPlot)
-  else
-  { 
-    if (printPlot)
-      print(plt)
-    invisible(plt)
-  }
+                              printPlot = FALSE)
+
+  #Deal with facetstrips.placement, if necessary, after everything else has been done
+  plt <- placeFacetStrips(plt, facetstrips.placement = facetstrips.placement)
+  
+  if (printPlot)
+    print(plt)
+  invisible(plt)
 }
 
 
@@ -214,7 +288,8 @@ getLinePosns <- function(axis.posns, endspace = 0.5)
 
 "designBlocksGGPlot" <- function(ggplot.obj, blockdefinition = NULL, blocksequence = FALSE, 
                                  originrow = 0, origincolumn = 0, nrows, ncolumns, 
-                                 blocklinecolour = "blue", blocklinesize = 2, printPlot = TRUE)
+                                 blocklinecolour = "blue", blocklinesize = 2, 
+                                 facetstrips.placement = "inside", printPlot = TRUE)
 {
   #This function is a modified version of code extracted from moddes.plot
   #It allows one to set the rectangle for plotting using 
@@ -227,6 +302,10 @@ getLinePosns <- function(axis.posns, endspace = 0.5)
   #Similarly, a single value for a column specifies a repetition of blocks of that size
   #     across the columns of the design, while several column values specifies a
   #     sequence of blocks across the columns of the size specified.
+  
+  opts <- c("inside", "outside.text", "outside.title")
+  facetstrips.placement <- opts[check.arg.values(facetstrips.placement, opts)]
+  
   if (!is.null(blockdefinition))
   { 
     rstart <- originrow
@@ -334,6 +413,9 @@ getLinePosns <- function(axis.posns, endspace = 0.5)
     }
   }
   
+  #Deal with facetstrips.placement, if necessary, after everything else has been done
+  ggplot.obj <- placeFacetStrips(ggplot.obj, facetstrips.placement = facetstrips.placement)
+  
   if (printPlot)
     print(ggplot.obj)
   invisible(ggplot.obj)
