@@ -547,7 +547,7 @@ test_that("Mostafa", {
   #Mostafa's green wall experiment in 2014
   data(gwall.lay)
   options(width = 100, nwarnings = 150)
-  set.daeTolerance(1e-06, 1e-06)
+  set.daeTolerance(1e-05, 1e-06)
   pot.treat.canon <- designAnatomy(formulae = list(pot = ~ Rows*Cols,
                                                    trt = ~ Species*Irrigation*Media + 
                                                      First/(SpeCarry*IrrCarry*MedCarry)), 
@@ -857,16 +857,17 @@ test_that("Exp249", {
   summary(Exp249.canon)
   testthat::expect_equal(length(Exp249.canon$Q[[1]]), 5)
   testthat::expect_lt(abs(Exp249.canon$Q[[2]]$'Zones&Groups'$'Lines'$adjusted$aefficiency - 0.1498311), 1e-05)
-  testthat::expect_lt(abs(Exp249.canon$Q[[2]]$'Rows[Zones:MainPosn]&Columns[Groups:Pairs]'$'Lines'$adjusted$aefficiency - 0.6639769), 1e-05)
+  testthat::expect_lt(abs(Exp249.canon$Q[[2]]$'Rows[Zones:MainPosn]&Columns[Groups:Pairs]'$'Lines'$adjusted$aefficiency - 0.6639769), 1e-02)
   testthat::expect_lt(abs(Exp249.canon$Q[[2]]$'Subplots[Zones:MainPosn:Rows]&Locations[Groups:Pairs:Columns]'$'Conditions'$adjusted$aefficiency - 1), 1e-05)
   testthat::expect_equal(Exp249.canon$Q[[3]]$'Rows[Zones:MainPosn]&Columns[Groups:Pairs]&Residual', 124)
   testthat::expect_equal(Exp249.canon$Q[[3]]$'Subplots[Zones:MainPosn:Rows]&Locations[Groups:Pairs:Columns]&Residual', 189)
   
   #'## Add factors and variates for new analysis
   Exp249.lay <- within(Exp249.lay, 
-                       { xMainPosn <- as.numfac(MainPosn)
-                       xMainPosn <- -(xMainPosn - mean(xMainPosn))
-                       Mainplots <- fac.combine(list(Rows,MainPosn))
+                       { 
+                         xMainPosn <- as.numfac(MainPosn)
+                         xMainPosn <- -(xMainPosn - mean(xMainPosn))
+                         Mainplots <- fac.combine(list(Rows,MainPosn))
                        })
 
   #'## Check properties if only linear trend fitted
@@ -883,24 +884,58 @@ test_that("Exp249", {
   testthat::expect_lt(abs(Exp249.canon$Q[[1]]$'Subplots[Zones:Mainplots]'$'Conditions'$adjusted$aefficiency - 1), 1e-05)
   testthat::expect_equal(Exp249.canon$Q[[2]]$'Mainplots[Zones]&Residual', 183)
   testthat::expect_equal(Exp249.canon$Q[[2]]$'Subplots[Zones:Mainplots]&Residual', 189)
+})
+
+  
+cat("#### Test for EXP249A - a two-phae, p-rep design\n")
+test_that("Exp249_All", {
+  skip_on_cran()
+  library(dae)
+  data(file="Exp249.mplot.sys")
+  Exp249.mplot.sys$Blocks <- factor(rep(1:6, each = 44))
+  
+  #'## Expand design to rerandomize lines and to assign conditions to locations
+  Exp249.recip <- list(Groups = 6, Columns = 4, Pairs = 11, Locations = 2)
+  Exp249.nest <- list(Columns = c("Groups", "Pairs"),
+                      Locations = c("Groups", "Columns", "Pairs"))
+  Exp249.alloc <- data.frame(Lines = factor(rep(Exp249.mplot.sys$Lines, each=2), 
+                                            levels=1:75),
+                             Checks = fac.recode(rep(Exp249.mplot.sys$Lines, each=2), 
+                                                 newlevels=c(rep(3, 73), 1 , 2), 
+                                                 labels = c("NAM","Scout","Gladius")),
+                             Conditions = factor(rep(1:2, times=264), 
+                                                 labels = c('0 NaCl','100 NaCl')))
+  Exp249.lay <- designRandomize(allocated = Exp249.alloc, 
+                                recipient = Exp249.recip, 
+                                nested.recipients = Exp249.nest, 
+                                seed = 51412)
+  
+  Exp249.lay <- cbind(fac.gen(list(Lanes = 24, Positions = 2:23)),
+                      fac.gen(list(Zones = 6, Rows = 4, MainPosn = 11, Subplots = 2)), 
+                      Exp249.lay)
+  
   
   Exp249.lay <- within(Exp249.lay, 
-                       {
+                       { 
+                         xMainPosn <- as.numfac(MainPosn)
+                         xMainPosn <- -(xMainPosn - mean(xMainPosn))
+                         Mainplots <- fac.combine(list(Rows,MainPosn))
                          AMainplots <- fac.combine(list(Zones, Mainplots))
                          ASubplots <- fac.combine(list(AMainplots,Subplots))
                        })
+  set.daeTolerance(1e-07,1e-07)
   Exp249A.canon <- designAnatomy(formulae = list(cart = ~Zones + AMainplots + ASubplots, 
                                                  treat = ~xMainPosn + (Checks + Lines) * Conditions),
                                  labels = "sources", data = Exp249.lay)
   summary(Exp249A.canon)
-  testthat::expect_equal(length(Exp249.canon$Q[[1]]), 3)
-  testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'Zones'$'Lines[Checks]'$adjusted$aefficiency - 0.1499827), 1e-05)
+  testthat::expect_equal(length(Exp249A.canon$Q[[1]]), 3)
+  testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'Zones'$'Lines[Checks]'$adjusted$aefficiency - 0.1499827), 1e-04)
   testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'AMainplots[Zones]'$'Lines[Checks]'$adjusted$aefficiency - 0.987877), 1e-05)
   testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'ASubplots[Zones:AMainplots]'$'Conditions'$adjusted$aefficiency - 1), 1e-05)
   testthat::expect_equal(Exp249A.canon$Q[[2]]$'AMainplots[Zones]&Residual', 183)
   testthat::expect_equal(Exp249A.canon$Q[[2]]$'ASubplots[Zones:AMainplots]&Residual', 189)
   
- })
+})
 
 
 cat("#### Test for Brien and Payne 3-tier sensory experiment\n")
